@@ -18,7 +18,7 @@ class Crawler:
         scraper = Scraper(response)
 
         href = scraper.gethref()
-        print(href)
+        print(href.contents)
     
     def isError(self, response): return isinstance(response, RequestError)
 
